ReturnHeaders

ns_write "Starting...<br>\n"

db_transaction {
  ns_write "Doing UROP professors...<br>\n"
  
  # create new fields
  
  set type phb_person
  
  ns_write "Moving existing attributes...<br>\n"
  
  # first, increment existing sort_orders to make "holes" for the new 
  # fields.  Do this starting with the largest numbers.
  set start_at [db_string get "select sort_order from acs_attributes where attribute_name = 'urop_1' and object_type = 'phb_person'"]
  db_foreach get "select attribute_name, sort_order from acs_attributes where object_type = :type and sort_order > [expr $start_at + 1] order by sort_order desc" {
    db_dml update "update acs_attributes set sort_order = [expr $sort_order + 2] where object_type = :type and attribute_name = :attribute_name"
  }
  
  # and move urop_2 up one, since we need to interleave the new fields
  db_dml update "update acs_attributes set sort_order = [expr $start_at + 2] where object_type = :type and attribute_name = 'urop_2'"
  
  # Now create the acs attributes
  
  ns_write "Creating new attributes...<br>\n"
  
  set order [expr $start_at + 1]
  foreach column { 
      {urop_professor_1
          {Professor 1} {Professor 1}       
          string {varchar(100)} {} }
      {urop_professor_2
          {Professor 2} {Professor 2}
          string {varchar(100)} {} }
  } {
      foreach {attribute pretty_name pretty_plural datatype column_spec default_value} $column { break }
  
      set column_spec [subst $column_spec]
  
      catch { cr::content_type::create_attribute \
                  -content_type $type \
                  -attribute_name $attribute \
                  -datatype $datatype \
                  -pretty_name $pretty_name \
                  -pretty_plural $pretty_plural \
                  -sort_order $order \
                  -default_value $default_value \
                  -column_spec $column_spec } err
      ns_write "$err\n"
  
      incr order 2
  }
  
  ns_write "Creating new widgets...<br>\n"
  
  # now create the corresponding display widgets (no display widget for the
  # privacy flag
  foreach widget {
      {urop_professor_1 text  optional {
          {size literal 60}
          {maxlength literal 100}}
      }
      {urop_professor_2 text  optional {
          {size literal 60}
          {maxlength literal 100}}
      }
  } {
      foreach {key widget required params} $widget { break }
      ns_write "Register: $key:$widget\n"
  
      cms_widget_register -content_type phb_person \
          -attribute $key \
          -widget $widget \
          -required=[string equal $required required] \
          -params $params
  }
  
  ns_write "Done with UROP professors...<br>\n"
}

db_transaction {
  ns_write "Doing past_employers...<br>\n"
  
  # delete fields to get rid of, if any
  
  ns_write "Deleting old attribute...<br>\n"
  
  set attribute_id [db_string s "select attribute_id from acs_attributes where attribute_name = 'past_employers'"]
  db_dml del_params {delete from cm_attribute_widget_params where attribute_id = :attribute_id}
  db_dml del_widget {delete from cm_attribute_widgets where attribute_id = :attribute_id}
  
  # I tried this, but got "no function with name 'DROP_ATTRIBUTE' exists in this scope"
  ## set result [db_exec_plsql create "
  ## begin
  ## :1 := content_type.drop_attribute (
  ##   content_type => 'phb_person',
  ##   attribute_name => 'past_employers',
  ##   drop_column => 'f');
  ## end;"]
  
  # not wanting to wait to figure that out, I did it the brute force way:
  db_dml del {delete from acs_attributes where object_type = 'phb_person' and attribute_name = 'past_employers'}
  db_dml del {delete from acs_attributes where object_type = 'phb_person' and attribute_name = 'priv_past_employers'}
  # seems to have worked... leaves the old field in the table so data can be 
  # retrieved
  
  # create replacement fields, if applicable
  
  set type phb_person
  
  ns_write "Moving existing attributes...<br>\n"
  
  # first, increment existing sort_orders to make "holes" for the new 
  # fields.  Do this starting with the largest numbers.
  db_foreach get "select attribute_name, sort_order from acs_attributes where object_type = :type and sort_order > 37 order by sort_order desc" {
    db_dml update "update acs_attributes set sort_order = [expr $sort_order + 3] where object_type = :type and attribute_name = :attribute_name"
  }
  
  # Now create the acs attributes
  
  ns_write "Creating new attributes...<br>\n"
  
  set order 38
  foreach column { 
      {past_employer_company_1
          {Company 1} {Company}       
          string {varchar(100)} {} }
      {past_employer_citystate_1
          {City/State 1} {City/State}       
          string {varchar(100)} {} }
      {past_employer_company_2
          {Company 2} {Professor}       
          string {varchar(100)} {} }
      {past_employer_citystate_2
          {City/State 2} {City/State}       
          string {varchar(100)} {} }
      {priv_past_employer
          {Suppress past employer} {Suppress past employer}
          integer integer  0 }
  
  } {
      foreach {attribute pretty_name pretty_plural datatype column_spec default_value} $column { break }
  
      set column_spec [subst $column_spec]
  
      catch { cr::content_type::create_attribute \
                  -content_type $type \
                  -attribute_name $attribute \
                  -datatype $datatype \
                  -pretty_name $pretty_name \
                  -pretty_plural $pretty_plural \
                  -sort_order $order \
                  -default_value $default_value \
                  -column_spec $column_spec } err
      ns_write "$err\n"
  
      incr order
  }
  
  ns_write "Creating new widgets...<br>\n"
  
  # now create the corresponding display widgets (no display widget for the
  # privacy flag
  foreach widget {
      {past_employer_company_1 text  optional {
          {size literal 60}
          {maxlength literal 100}}
      }
      {past_employer_citystate_1 text  optional {
          {size literal 60}
          {maxlength literal 100}}
      }
      {past_employer_company_2 text  optional {
          {size literal 60}
          {maxlength literal 100}}
      }
      {past_employer_citystate_2 text  optional {
          {size literal 60}
          {maxlength literal 100}}
      }
  } {
      foreach {key widget required params} $widget { break }
      ns_write "Register: $key:$widget\n"
  
      cms_widget_register -content_type phb_person \
          -attribute $key \
          -widget $widget \
          -required=[string equal $required required] \
          -params $params
  }
  
  ns_write "Moving existing data to new fields...<br>\n"
  
  # and finally, move the old data to the new field.  should delete the old field
  # once this is for sure ok
  db_foreach update "SELECT p.past_employers, p.user_id
              FROM phb_personx p, cr_items i
              WHERE p.item_id = i.item_id
                and p.revision_id = i.live_revision
                and p.past_employers is not null" {
    if { [string length $past_employers] > 100 } {
       set past_employers [string range $past_employers 0 99]
       db_dml update "update phb_person set past_employer_company_1 = :past_employers where user_id = :user_id"
    }
  }
  
  ns_write "Done with past employers...<br>\n"
}

db_transaction {
  ns_write "Doing internship...<br>\n"
  
  # don't delete this time - the institution field is used by other data
  # types that use phb_span
   
  # create new fields
  
  set type phb_span
  
  ns_write "Moving existing attributes...<br>\n"
  
  # first, increment existing sort_orders to make "holes" for the new 
  # fields.  Do this starting with the largest numbers.  Leave the existing
  # institution field where it is and add the new ones after it.
  set start_at [db_string get "select sort_order from acs_attributes where attribute_name = 'institution' and object_type = 'phb_span'"]
  db_foreach get "select attribute_name, sort_order from acs_attributes where object_type = :type and sort_order > $start_at order by sort_order desc" {
    db_dml update "update acs_attributes set sort_order = [expr $sort_order + 3] where object_type = :type and attribute_name = :attribute_name"
  }
  
  # Now create the acs attributes
  
  ns_write "Creating new attributes...<br>\n"
  
  set order [expr $start_at + 1]
  foreach column { 
      {institution_position
          {Institution Position} {Institution Position}
          string varchar(200) {} }
      {institution_company
          {Institution Company} {Institution Company}
          string varchar(200) {} }
      {institution_city
          {Institution City} {Institution City}
          string varchar(200) {} }
      {institution_state
          {Institution State} {Institution State}
          string varchar(200) {} }
  } {
      foreach {attribute pretty_name pretty_plural datatype column_spec default_value} $column { break }
  
      set column_spec [subst $column_spec]
  
      catch { cr::content_type::create_attribute \
                  -content_type $type \
                  -attribute_name $attribute \
                  -datatype $datatype \
                  -pretty_name $pretty_name \
                  -pretty_plural $pretty_plural \
                  -sort_order $order \
                  -default_value $default_value \
                  -column_spec $column_spec } err
      ns_write "$err\n"
  
      incr order
  }
  
  ns_write "Creating new widgets...<br>\n"
  
  # now create the corresponding display widgets (no display widget for the
  # privacy flag
  foreach widget {
      {institution_position text optional {
          {size literal 60}
          {maxlength literal 200} }
      }
      {institution_company text optional {
          {size literal 60}
          {maxlength literal 200} }
      }
      {institution_city text optional {
          {size literal 60}
          {maxlength literal 200} }
      }
      {institution_state text optional {
          {size literal 60}
          {maxlength literal 200} }
      }
  } {
      foreach {key widget required params} $widget { break }
      ns_write "Register: $key:$widget\n"
  
      cms_widget_register -content_type phb_span \
          -attribute $key \
          -widget $widget \
          -required=[string equal $required required] \
          -params $params
  }
  
  ns_write "Moving existing data to new fields...<br>\n"
  
  # and finally, move the old data to the new field.  should delete the old field
  # once this is for sure ok
  db_foreach update "SELECT t.span_id, t.institution
      FROM phb_spanx t, cr_items i, cr_child_rels r
      WHERE t.revision_id = i.live_revision
        and r.parent_id = i.parent_id
        and r.child_id = i.item_id
        and t.institution is not null
        and r.relation_tag = 'internship'
      GROUP BY span_id, institution" {
      db_dml update "update phb_span set institution_company = :institution where span_id = :span_id"
  }
  
  ns_write "Done with internship...<br>\n"
}

ns_write "Done...<br>\n"

# other things to edit:
#in tcl/photobook-procs.tcl, every field group that uses phb_span has to include all the fields, with the extra internship ones turned off.

#lib/person.tcl and lib/person-employment.adp both referred to the old internship fields and needed to be updated

